@@ -4,7 +4,8 @@ test_that('fortify.forecast works for AirPassengers', {
   d.arima <- forecast::auto.arima(AirPassengers)
   d.forecast <- forecast::forecast(d.arima, level = c(95), h = 50)
 
-  expect_that(ggplot2::autoplot(d.forecast), not(throws_error()))
+  p <- ggplot2::autoplot(d.forecast)
+  expect_true(is(p, 'ggplot'))
 
   fortified <- ggplot2::fortify(d.forecast)
   expect_equal(is.data.frame(fortified), TRUE)
